@@ -5,7 +5,11 @@ model{
  for(i in 1:len){
   p[i] <- phi(mu[t[i]] + vi[s[i], t[i]])
   r[i] ~ dbin(p[i], totaln[i])
+  rhat[i] <- p[i]*totaln[i]
+  dev[i] <- 2*(r[i]*(log(r[i]) - log(rhat[i])) +
+    (totaln[i] - r[i])*(log(totaln[i] - r[i]) - log(totaln[i] - rhat[i])))
  }
+ totresdev <- sum(dev[])
  for(j in 1:nstudy){
   vi[j, 1:ntrt] ~ dmnorm(zeros[1:ntrt], T[1:ntrt, 1:ntrt])
  }
@@ -45,7 +49,11 @@ model{
  for(i in 1:len){
   p[i] <- phi(mu[t[i]] + vi[s[i], t[i]])
   r[i] ~ dbin(p[i], totaln[i])
+  rhat[i] <- p[i]*totaln[i]
+  dev[i] <- 2*(r[i]*(log(r[i]) - log(rhat[i])) +
+    (totaln[i] - r[i])*(log(totaln[i] - r[i]) - log(totaln[i] - rhat[i])))
  }
+ totresdev <- sum(dev[])
  for(j in 1:nstudy){
   vi[j, 1:ntrt] ~ dmnorm(zeros[1:ntrt], T[1:ntrt, 1:ntrt])
  }
@@ -81,7 +89,11 @@ model{
  for(i in 1:len){
   p[i] <- phi(mu[t[i]] + vi[s[i], t[i]])
   r[i] ~ dbin(p[i], totaln[i])
+  rhat[i] <- p[i]*totaln[i]
+  dev[i] <- 2*(r[i]*(log(r[i]) - log(rhat[i])) +
+    (totaln[i] - r[i])*(log(totaln[i] - r[i]) - log(totaln[i] - rhat[i])))
  }
+ totresdev <- sum(dev[])
  for(j in 1:nstudy){
   vi[j, 1:ntrt] ~ dmnorm(zeros[1:ntrt], T[1:ntrt, 1:ntrt])
  }
@@ -122,7 +134,11 @@ model{
  for(i in 1:len){
   p[i] <- phi(mu[t[i]] + vi[s[i], t[i]])
   r[i] ~ dbin(p[i], totaln[i])
+  rhat[i] <- p[i]*totaln[i]
+  dev[i] <- 2*(r[i]*(log(r[i]) - log(rhat[i])) +
+    (totaln[i] - r[i])*(log(totaln[i] - r[i]) - log(totaln[i] - rhat[i])))
  }
+ totresdev <- sum(dev[])
  for(j in 1:nstudy){
   vi[j,1:ntrt] ~ dmnorm(zeros[1:ntrt], T[1:ntrt, 1:ntrt])
  }
